@@ -2,6 +2,7 @@
 #include <QDeclarativeView>
 #include <QDebug>
 #include <QFile>
+#include <QDir>
 
 #ifdef Q_WS_MAEMO_5
 #include <QtDBus/QDBusConnection>
@@ -94,6 +95,26 @@ void Controller::deleteVideo(const QString &path) {
     }
 }
 
+QString Controller::archiveFileExists(const QString &filePath, const QString &archivePath) {
+    QString result = "Not found";
+    if (QFile::exists(filePath)) {
+        result = "Unchanged";
+    }
+    else {
+        QString newPath = archivePath;
+        newPath.append(filePath.split("/").last());
+        if (QFile::exists(newPath)) {
+            result = newPath;
+        }
+    }
+    return result;
+}
+
+bool Controller::pathExists(const QString &path) {
+    QDir dir(path);
+    return dir.exists();
+}
+
 void Controller::convertToAudio(const QString &input) {
     inputFile = input;
     QString ffmpeg = "/usr/bin/ffmpeg";
